@@ -25,8 +25,8 @@ def openBam(bamFile, bamIndex=None):
         tmpf0bam_name = '%s.bam' % tmpf0_name
         tmpf0bambai_name = '%s.bam.bai' % tmpf0_name
 
-        os.symlink(bamFile, tmpf0bam_name)
-        os.symlink(bamIndex, tmpf0bambai_name)
+        os.symlink(os.path.abspath(bamFile), tmpf0bam_name)
+        os.symlink(os.path.abspath(bamIndex), tmpf0bambai_name)
         bamFile = tmpf0bam_name
 
     else:
@@ -44,6 +44,9 @@ def openBam(bamFile, bamIndex=None):
         sys.exit("The file {} does not have BAM format ".format(bamFile))
 
     if bam.mapped == 0:
-        sys.exit("The file {} does have any mapped reads. ".format(bamFile))
+        sys.exit("Samtools reports that the number of mapped "
+                 "reads is zero for the file {}. Please check "
+                 "that the file is properly indexed and that "
+                 "it contains mapped reads.".format(bamFile))
 
     return bam
